# -*- mode: org -*-

#+STARTUP: showall

#+LINK: sym file:snippet-reference.org::#%s

#+OPTIONS: author:nil num:nil timestamp:nil
#+AUTHOR:
# org < 8.0 use +STYLE, after use +HTML_HEAD
#+STYLE: <link rel="stylesheet" type="text/css" href="stylesheets/manual.css" />
#+HTML_HEAD: <link rel="stylesheet" type="text/css" href="stylesheets/manual.css" />
